@@ -22,7 +22,7 @@ class ClinicalDataOutboxResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['date']
 
         in_data = pre_load_date_fields(
@@ -33,12 +33,12 @@ class ClinicalDataOutboxResourceSchema(Schema):
         return in_data
 
     @pre_load
-    def check_source_ids(self, in_data):
+    def check_source_ids(self, in_data, **kwargs):
         if self._get_number_of_source_fields(in_data) != 1:
             raise ValidationError('Provide either news_id or '
                                   'pubmed_id, not both')
 
-    def _get_number_of_source_fields(self, in_data):
+    def _get_number_of_source_fields(self, in_data, **kwargs):
         result = 0
         if 'news_id' in in_data:
             if in_data['news_id'] is not None:
