@@ -30,6 +30,8 @@ class CompanyFilingModel(Base):
         ForeignKey('files.id'),
         nullable=False,
     )
+    date = Column(DateTime, nullable=True)
+    title = Column(String(255), nullable=True)
     type = Column(String(255), nullable=True)
     orig_file_url = Column(String(255), nullable=True)
     is_deleted = Column(Boolean, nullable=True)
