@@ -18,12 +18,13 @@ class CompanyLicensingCollabResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def pre_load(self, in_data):
+    def pre_load(self, in_data, **kwargs):
         if self._get_number_of_company_fields(in_data) > 1:
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id, not both')
+        return in_data
 
-    def _get_number_of_company_fields(self, in_data):
+    def _get_number_of_company_fields(self, in_data, **kwargs):
         result = 0
         if 'company_sec_id' in in_data:
             if in_data['company_sec_id'] is not None:
