@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Float,
+    Boolean,
 )
 
 from ...database import Base
@@ -29,6 +30,7 @@ class ConditionNewswireModel(Base):
         Float,
         nullable=False,
     )
+    preferred = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
