@@ -23,11 +23,11 @@ class InterventionDataResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def check_resource_info(self, in_data):
+    def check_resource_info(self, in_data, **kwargs):
         if self._get_number_of_source_fields(in_data) != 1:
             raise ValidationError('Provide only one source info')
 
-    def _get_number_of_source_fields(self, in_data):
+    def _get_number_of_source_fields(self, in_data, **kwargs):
         result = 0
         if 'news_id' in in_data:
             if in_data['news_id'] is not None:
@@ -41,7 +41,7 @@ class InterventionDataResourceSchema(Schema):
         return result
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['date']
 
         in_data = pre_load_date_fields(
