@@ -25,7 +25,7 @@ class MergerResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['announcement_date']
 
         in_data = pre_load_date_fields(
@@ -36,7 +36,7 @@ class MergerResourceSchema(Schema):
         return in_data
 
     @pre_load
-    def check_target_acquirer_ids(self, in_data):
+    def check_target_acquirer_ids(self, in_data, **kwargs):
         if self._get_number_of_target_company_fields(in_data) != 1:
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id for target, not both')
@@ -44,7 +44,7 @@ class MergerResourceSchema(Schema):
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id for acquirer, not both')
 
-    def _get_number_of_target_company_fields(self, in_data):
+    def _get_number_of_target_company_fields(self, in_data, **kwargs):
         result = 0
         if 'target_sec_id' in in_data:
             if in_data['target_sec_id'] is not None:
@@ -54,7 +54,7 @@ class MergerResourceSchema(Schema):
                 result += 1
         return result
 
-    def _get_number_of_acquirer_company_fields(self, in_data):
+    def _get_number_of_acquirer_company_fields(self, in_data, **kwargs):
         result = 0
         if 'acquirer_sec_id' in in_data:
             if in_data['acquirer_sec_id'] is not None:
@@ -78,7 +78,7 @@ class MergerQueryParamsSchema(Schema):
     announcement_date = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['announcement_date']
 
         in_data = pre_load_date_fields(
@@ -104,7 +104,7 @@ class MergerPatchSchema(Schema):
     dma_file_id = fields.Integer()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['announcement_date']
 
         in_data = pre_load_date_fields(
@@ -115,7 +115,7 @@ class MergerPatchSchema(Schema):
         return in_data
 
     @pre_load
-    def check_target_acquirer_ids(self, in_data):
+    def check_target_acquirer_ids(self, in_data, **kwargs):
         if self._get_number_of_target_company_fields(in_data) != 1:
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id for target, not both')
@@ -123,7 +123,7 @@ class MergerPatchSchema(Schema):
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id for acquirer, not both')
 
-    def _get_number_of_target_company_fields(self, in_data):
+    def _get_number_of_target_company_fields(self, in_data, **kwargs):
         result = 0
         if 'target_sec_id' in in_data:
             if in_data['target_sec_id'] is not None:
@@ -133,7 +133,7 @@ class MergerPatchSchema(Schema):
                 result += 1
         return result
 
-    def _get_number_of_acquirer_company_fields(self, in_data):
+    def _get_number_of_acquirer_company_fields(self, in_data, **kwargs):
         result = 0
         if 'acquirer_sec_id' in in_data:
             if in_data['acquirer_sec_id'] is not None:
