@@ -25,7 +25,7 @@ class PatentApplicationResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = [
             'filed_date',
         ]
