@@ -29,13 +29,13 @@ class StreamResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def check_resource_info(self, in_data):
+    def check_resource_info(self, in_data, **kwargs):
         if self._get_number_of_resource_fields(in_data) == 0:
             raise ValidationError('Provide at least one resource info')
         if self._get_number_of_source_fields(in_data) != 1:
             raise ValidationError('Provide only one source info')
 
-    def _get_number_of_resource_fields(self, in_data):
+    def _get_number_of_resource_fields(self, in_data, **kwargs):
         result = 0
         if 'intervention_id' in in_data:
             if in_data['intervention_id'] is not None:
@@ -54,7 +54,7 @@ class StreamResourceSchema(Schema):
                 result += 1
         return result
 
-    def _get_number_of_source_fields(self, in_data):
+    def _get_number_of_source_fields(self, in_data, **kwargs):
         result = 0
         if 'news_id' in in_data:
             if in_data['news_id'] is not None:
@@ -74,7 +74,7 @@ class StreamResourceSchema(Schema):
         return result
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['date']
 
         in_data = pre_load_date_fields(
